@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /cvsroot/pgpool/pgpool/child.c,v 1.3 2005/07/18 01:42:48 t-ishii Exp $
+ * $Header: /cvsroot/pgpool/pgpool/child.c,v 1.4 2005/09/02 14:28:20 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -954,6 +954,7 @@ int health_check(void)
 		pool_error("health check failed during write. master %s at port %d is down",
 				   pool_config.current_backend_host_name,
 				   pool_config.current_backend_port);
+		close(fd);
 		return -1;
 	}
 
@@ -964,6 +965,7 @@ int health_check(void)
 		pool_error("health check failed during write. master %s at port %d is down",
 				   pool_config.current_backend_host_name,
 				   pool_config.current_backend_port);
+		close(fd);
 		return -1;
 	}
 
@@ -987,20 +989,22 @@ int health_check(void)
 
 	if (write(fd, &mysp, sizeof(mysp)) < 0)
 	{
-		pool_error("health check failed during write. master %s at port %d is down",
-				   pool_config.current_backend_host_name,
-				   pool_config.current_backend_port);
-		return -1;
+		pool_error("health check failed during write. secondary %s at port %d is down",
+				   pool_config.secondary_backend_host_name,
+				   pool_config.secondary_backend_port);
+		close(fd);
+		return -2;
 	}
 
 	read(fd, &kind, 1);
 
 	if (write(fd, "X", 1) < 0)
 	{
-		pool_error("health check failed during write. master %s at port %d is down",
-				   pool_config.current_backend_host_name,
-				   pool_config.current_backend_port);
-		return -1;
+		pool_error("health check failed during write. secondary %s at port %d is down",
+				   pool_config.secondary_backend_host_name,
+				   pool_config.secondary_backend_port);
+		close(fd);
+		return -2;
 	}
 
 	close(fd);
