@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /cvsroot/pgpool/pgpool/main.c,v 1.6 2005/06/25 00:58:46 t-ishii Exp $
+ * $Header: /cvsroot/pgpool/pgpool/main.c,v 1.8 2005/09/02 14:24:54 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -170,7 +170,7 @@ int main(int argc, char **argv)
 	if (pool_get_config(conf_file))
 	{
 		pool_error("Unable to get configuration. Exiting...");
-		mypid = getpid();
+		mypid = 0;		/* do not delete UNIX domain socket or pid file */
 		myexit(1);
 	}
 
@@ -183,6 +183,9 @@ int main(int argc, char **argv)
 						   (pool_config.weight_master + pool_config.weight_secondary));
 	pool_debug("weight: %ld", weight_master);
 
+	/*
+	 * if a non-switch argument remains, then it should be either "stop" or "switch"
+	 */
 	if (optind == (argc - 1))
 	{
 		if (!strcmp(argv[optind], "stop"))
@@ -195,7 +198,15 @@ int main(int argc, char **argv)
 			switch_me();
 			exit(0);
 		}
+		else
+		{
+			usage();
+			exit(1);
+		}
 	}
+	/*
+	 * else if no non-switch argument remains, then it should be a start request
+	 */
 	else if (optind == argc)
 	{
 		pid = read_pid_file();
@@ -210,13 +221,15 @@ int main(int argc, char **argv)
 				fprintf(stderr, "pid file found but it seems bogus. Trying to start pgpool anyway...\n");
 		}
 	}
-	else if (optind < argc)
+	/*
+	 * otherwise an error...
+	 */
+	else
 	{
 		usage();
 		exit(1);
 	}
 
-
 	/* set signal masks */
 	poolinitmask();
 
@@ -848,7 +861,7 @@ static RETSIGTYPE failover_handler(int sig)
 		{
 			if (sig == SIGUSR2)
 			{
-				pool_log("degenration done. shutdown secondary host %s(%d)",
+				pool_log("degeneration done. shutdown secondary host %s(%d)",
 						 pool_config.secondary_backend_host_name,
 						 pool_config.secondary_backend_port);
 			}
